package com.diagbot.facade;

import com.alibaba.fastjson.JSON;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.diagbot.dto.GetTopPatientInfoDjDTO;
import com.diagbot.dto.RegisterInfoDTO;
import com.diagbot.dto.SignInDTO;
import com.diagbot.entity.DoctorInfo;
import com.diagbot.entity.HospitalDept;
import com.diagbot.entity.HospitalInfo;
import com.diagbot.entity.PatientInfo;
import com.diagbot.entity.SysSet;
import com.diagbot.enums.SysTypeEnum;
import com.diagbot.enums.VisibleIdTypeEnum;
import com.diagbot.exception.CommonException;
import com.diagbot.exception.ServiceErrorCode;
import com.diagbot.idc.VisibleIdCreater;
import com.diagbot.service.DoctorInfoService;
import com.diagbot.service.HospitalDeptService;
import com.diagbot.service.impl.PatientInfoServiceImpl;
import com.diagbot.util.BeanUtil;
import com.diagbot.util.DateUtil;
import com.diagbot.util.IdCard;
import com.diagbot.util.ListUtil;
import com.diagbot.util.StringUtil;
import com.diagbot.vo.GetTopPatientInfoDjVO;
import com.diagbot.vo.InquiryQuoteVO;
import com.diagbot.vo.SignInVO;
import com.google.common.collect.Lists;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.stereotype.Component;

import java.util.Date;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * @Description: 对接-患者业务逻辑
 * @author: wangyu
 * @time: 2018/11/19 13:19
 */
@Component
public class PatientInfoDjFacade extends PatientInfoServiceImpl {
    @Autowired
    private HospitalInfoFacade hospitalInfoFacade;
    @Autowired
    private HospitalDeptFacade hospitalDeptFacade;
    @Autowired
    @Qualifier("hospitalDeptServiceImpl")
    private HospitalDeptService hospitalDeptService;
    @Autowired
    private DoctorInfoFacade doctorInfoFacade;
    @Autowired
    @Qualifier("doctorInfoServiceImpl")
    private DoctorInfoService doctorInfoService;
    @Autowired
    private SysSetFacade sysSetFacade;
    @Autowired
    private VisibleIdCreater visibleIdCreater;

    /**
     * 对接-页面顶部病人医生科室信息——查询
     *
     * @param getTopPatientInfoDjVO
     * @return
     */
    public GetTopPatientInfoDjDTO getTopPatientInfoDj(GetTopPatientInfoDjVO getTopPatientInfoDjVO) {
        GetTopPatientInfoDjDTO getTopPatientInfoDjDTO = this.baseMapper.getTopPatientInfoDj(getTopPatientInfoDjVO);
        getTopPatientInfoDjDTO.setSystemTime(DateUtil.now());
        getTopPatientInfoDjDTO.setRecordId(getTopPatientInfoDjVO.getRecordId());
        getTopPatientInfoDjDTO.setPatientAge(DateUtil.yearCompare(getTopPatientInfoDjDTO.getBirthday(), DateUtil.now()));

        List<String> hospitalCodeList = Lists.newArrayList();
        hospitalCodeList.add(getTopPatientInfoDjVO.getHospitalCode());
        if (StringUtil.isNotBlank(getTopPatientInfoDjVO.getSonHospitalCode())) {
            hospitalCodeList.add(getTopPatientInfoDjVO.getSonHospitalCode());
        }
        QueryWrapper<HospitalInfo> hospitalInfoQe = new QueryWrapper<>();
        hospitalInfoQe.in("code", hospitalCodeList);
        Map<String, HospitalInfo> hospitalInfoMap = hospitalInfoFacade.list(hospitalInfoQe)
                .stream().collect(Collectors.toMap(HospitalInfo::getCode, i -> i));

        HospitalInfo hospitalInfo = hospitalInfoMap.get(getTopPatientInfoDjVO.getHospitalCode());
        HospitalInfo sonHospitalInfo = hospitalInfoMap.get(getTopPatientInfoDjVO.getSonHospitalCode());
        getTopPatientInfoDjDTO.setHospitalId(hospitalInfo.getId());
        getTopPatientInfoDjDTO.setHospitalCode(hospitalInfo.getCode());
        getTopPatientInfoDjDTO.setHospitalName(hospitalInfo.getName());
        if (sonHospitalInfo != null) {
            getTopPatientInfoDjDTO.setSonHospitalId(sonHospitalInfo.getId());
            getTopPatientInfoDjDTO.setSonHospitalCode(sonHospitalInfo.getCode());
            getTopPatientInfoDjDTO.setSonHospitalName(sonHospitalInfo.getName());
        }

        QueryWrapper<HospitalDept> hospitalDeptQe = new QueryWrapper<>();
        hospitalDeptQe.eq("hospital_code",
                StringUtil.isBlank(getTopPatientInfoDjVO.getSonHospitalCode())
                        ? getTopPatientInfoDjVO.getHospitalCode()
                        : getTopPatientInfoDjVO.getSonHospitalCode());
        hospitalDeptQe.eq("code", getTopPatientInfoDjVO.getHospitalDeptCode());
        HospitalDept hospitalDept = hospitalDeptFacade.getOne(hospitalDeptQe, false);
        if (hospitalDept != null) {
            getTopPatientInfoDjDTO.setHospitalDeptId(hospitalDept.getId());
            getTopPatientInfoDjDTO.setHospitalDeptCode(hospitalDept.getCode());
            getTopPatientInfoDjDTO.setHospitalDeptName(hospitalDept.getName());
            getTopPatientInfoDjDTO.setSelfDeptName(hospitalDept.getConceptDeptName());
        }

        return getTopPatientInfoDjDTO;
    }

    /**
     * 患者登录
     *
     * @param signInVO
     * @return
     */
    public List<SignInDTO> signIn(SignInVO signInVO) {
        List<SignInDTO> retList = null;

        List<RegisterInfoDTO> rifList = getRegisterInfo(signInVO);
        if (ListUtil.isNotEmpty(rifList)) {
            generateByRif(rifList);
            retList = rifConverSin(rifList);
        } else {
            retList = autoGenePatinfo(signInVO);
        }

        if (retList == null) {
            throw new CommonException(ServiceErrorCode.IQC_NOT_FOUND);
        }

        return retList;
    }

    /**
     * 自动生成患者信息
     *
     * @param signInVO
     * @return
     */
    private List<SignInDTO> autoGenePatinfo(SignInVO signInVO) {
        QueryWrapper<SysSet> sysSetQe = new QueryWrapper<>();
        sysSetQe.eq("sys_type", SysTypeEnum.PREC_SERVICE.getKey());
        sysSetQe.and(qe1 -> qe1
                .and(qe2 -> qe2
                        .eq("hospital_code", signInVO.getHospitalCode())
                        .eq("code", "patientinfo"))
                .or(qe3 -> qe3
                        .eq("hospital_code",
                                StringUtil.isBlank(signInVO.getSonHospitalCode()) ? signInVO.getHospitalCode()
                                        : signInVO.getSonHospitalCode())
                        .eq("code", "default_dept")));
        Map<String, String> sysSetCodeValue = sysSetFacade.list(sysSetQe).stream()
                .collect(Collectors.toMap(SysSet::getCode, i -> i.getValue()));

        if (StringUtil.isBlank(sysSetCodeValue.get("patientinfo"))
                || !sysSetCodeValue.get("patientinfo").equals("1")) {
            return null;
        }
        if (!signInVO.getPatientInfoType().equals("101")) {
            throw new CommonException(ServiceErrorCode.IDCARD_LOGIN);
        }

        List<SignInDTO> retList = Lists.newArrayList();
        SignInDTO signInDTO = new SignInDTO();
        signInDTO.setHospitalCode(signInVO.getHospitalCode());
        signInDTO.setHospitalName(signInVO.getHospitalName());
        signInDTO.setSonHospitalCode(signInVO.getSonHospitalCode());
        signInDTO.setSonHospitalName(signInVO.getSonHospitalName());

        String hospitalDeptCode = sysSetCodeValue.get("default_dept");
        signInDTO.setHospitalDeptCode(hospitalDeptCode);

        QueryWrapper<HospitalDept> hospitalDeptQe = new QueryWrapper<>();
        hospitalDeptQe.eq("hospital_code",
                StringUtil.isBlank(signInVO.getSonHospitalCode()) ? signInVO.getHospitalCode() : signInVO.getSonHospitalCode());
        hospitalDeptQe.eq("code", hospitalDeptCode);
        signInDTO.setHospitalDeptName(hospitalDeptFacade.getOne(hospitalDeptQe, false).getName());

        QueryWrapper<PatientInfo> patientInfoQe = new QueryWrapper<>();
        patientInfoQe.eq("hospital_code", signInVO.getHospitalCode());
        patientInfoQe.eq("name", signInVO.getPatientName());
        patientInfoQe.and(a ->
                a.eq("id_no", signInVO.getPatientInfo()).or().eq("identity_num", signInVO.getPatientInfo()));
        PatientInfo patientInfo = getOne(patientInfoQe, false);
        if (patientInfo == null) {
            patientInfo = new PatientInfo();
            patientInfo.setGmtCreate(DateUtil.now());
            patientInfo.setHospitalCode(signInVO.getHospitalCode());
            patientInfo.setIdNo(signInVO.getPatientInfo());
            patientInfo.setIdentityNum(signInVO.getPatientInfo());
            patientInfo.setName(signInVO.getPatientName());
            patientInfo.setSex(IdCard.getGenderByIdCard(signInVO.getPatientInfo()));
            patientInfo.setBirthday(DateUtil.parseDate(IdCard.getBirthByIdCard(signInVO.getPatientInfo()), "yyyyMMdd"));

            patientInfo.setCode("" + visibleIdCreater.getNextShortId(VisibleIdTypeEnum.PATIENT_NO.getKey()));
            patientInfo.setRemark("1");//自动生成标志

            save(patientInfo);
        }
        signInDTO.setPatientCode(patientInfo.getCode());
        signInDTO.setPatientName(patientInfo.getName());

        retList.add(signInDTO);
        return retList;
    }

    /**
     * his返回的挂号信息转化给前端
     *
     * @param rifList
     * @return
     */
    private List<SignInDTO> rifConverSin(List<RegisterInfoDTO> rifList) {
        List<SignInDTO> retList = Lists.newArrayList();
        rifList.forEach(rif -> {
            rif.getDetail().forEach(i -> {
                SignInDTO signInDTO = new SignInDTO(
                        rif.getHospitalCode(),
                        rif.getHospitalName(),
                        rif.getSonHospitalCode(),
                        rif.getSonHospitalName(),
                        i.getHospitalDeptCode(),
                        i.getHospitalDeptName(),
                        i.getDoctorInfo() == null ? null : i.getDoctorInfo().getCode(),
                        i.getDoctorInfo() == null ? null : i.getDoctorInfo().getName(),
                        rif.getPatientInfo().getCode(),
                        rif.getPatientInfo().getName(),
                        i.getRecordTime(),
                        i.getRecordId(),
                        i.getRegisterNum()
                );
                retList.add(signInDTO);
            });
        });
        return retList;
    }

    /**
     * 由挂号信息检查病人科室医生信息，有更新，无插入
     *
     * @param rifList
     */
    private void generateByRif(List<RegisterInfoDTO> rifList) {
        String hospitalCode = rifList.get(0).getHospitalCode();
        String hospitalName = rifList.get(0).getHospitalName();
        PatientInfo patientInfo = rifList.get(0).getPatientInfo();
        QueryWrapper<PatientInfo> patientInfoQe = new QueryWrapper<>();
        patientInfoQe.eq("hospital_code", hospitalCode);
        patientInfoQe.eq("code", patientInfo.getCode());
        PatientInfo patientInfoQuery = getOne(patientInfoQe, false);
        PatientInfo saveOrUpat = new PatientInfo();
        Long patId = null;
        if (patientInfoQuery != null) {
            patId = patientInfoQuery.getId();
            BeanUtil.copyProperties(patientInfoQuery, saveOrUpat);
        }
        BeanUtil.copyProperties(patientInfo, saveOrUpat);
        saveOrUpat.setId(patId);
        saveOrUpat.setHospitalCode(hospitalCode);
        saveOrUpdate(saveOrUpat);

        List<String> doctorCodeList = Lists.newArrayList();
        List<DoctorInfo> doctorInfoList = Lists.newArrayList();
        rifList.forEach(rif -> {
            String sonHospitalCode = rif.getSonHospitalCode();
            String sonHospitalName = rif.getSonHospitalName();

            List<String> deptCodeList = rif.getDetail().stream()
                    .filter(i -> StringUtil.isNotBlank(i.getHospitalDeptCode()) && StringUtil.isNotBlank(i.getHospitalDeptName()))
                    .map(i -> i.getHospitalDeptCode())
                    .collect(Collectors.toList());
            QueryWrapper<HospitalDept> hospitalDeptQe = new QueryWrapper<>();
            hospitalDeptQe.eq("hospital_code", StringUtil.isBlank(sonHospitalCode) ? hospitalCode : sonHospitalCode);
            hospitalDeptQe.in("code", deptCodeList);
            Map<String, HospitalDept> deptMap = hospitalDeptFacade.list(hospitalDeptQe)
                    .stream()
                    .collect(Collectors.toMap(HospitalDept::getCode, i -> i));
            List<HospitalDept> deptSaveOrUpdateList = Lists.newArrayList();
            rif.getDetail().stream()
                    .filter(i -> StringUtil.isNotBlank(i.getHospitalDeptCode()) && StringUtil.isNotBlank(i.getHospitalDeptName()))
                    .forEach(i -> {
                        HospitalDept hospitalDeptQuery = deptMap.get(i.getHospitalDeptCode());
                        if (hospitalDeptQuery == null) {
                            HospitalDept hospitalDept = new HospitalDept();
                            hospitalDept.setHospitalCode(StringUtil.isNotBlank(sonHospitalCode) ? sonHospitalCode : hospitalCode);
                            hospitalDept.setHospitalName(StringUtil.isNotBlank(sonHospitalCode) ? sonHospitalName : hospitalName);
                            hospitalDept.setCode(i.getHospitalDeptCode());
                            hospitalDept.setName(i.getHospitalDeptName());
                            hospitalDept.setconceptDeptName("全科");
                            deptSaveOrUpdateList.add(hospitalDept);
                        } else {
                            hospitalDeptQuery.setName(i.getHospitalDeptName());
                            deptSaveOrUpdateList.add(hospitalDeptQuery);
                        }
                    });
            if (ListUtil.isNotEmpty(deptSaveOrUpdateList)) {
                hospitalDeptService.saveOrUpdateBatch(deptSaveOrUpdateList);
            }

            rif.getDetail().stream()
                    .filter(i -> i.getDoctorInfo() != null).map(i -> i.getDoctorInfo())
                    .filter(i -> StringUtil.isNotBlank(i.getCode()) && StringUtil.isNotBlank(i.getName()))
                    .forEach(i -> {
                        doctorCodeList.add(i.getCode());
                        doctorInfoList.add(i);
                    });
        });

        if (ListUtil.isEmpty(doctorCodeList)) {
            return;
        }

        QueryWrapper<DoctorInfo> doctorInfoQe = new QueryWrapper<>();
        doctorInfoQe.eq("hospital_code", hospitalCode);
        doctorInfoQe.in("code", doctorCodeList);
        Map<String, DoctorInfo> doctorMap = doctorInfoFacade.list(doctorInfoQe)
                .stream().collect(Collectors.toMap(DoctorInfo::getCode, i -> i));
        List<DoctorInfo> doctorSaveOrUpdateList = Lists.newArrayList();
        doctorInfoList.forEach(i -> {
            DoctorInfo doctorInfoQuery = doctorMap.get(i.getCode());
            DoctorInfo doctorInfo = new DoctorInfo();
            Long docId = null;
            if (doctorInfoQuery != null) {
                docId = doctorInfoQuery.getId();
                BeanUtil.copyProperties(doctorInfoQuery, doctorInfo);
            }
            BeanUtil.copyProperties(i, doctorInfo);
            doctorInfo.setHospitalCode(hospitalCode);
            doctorInfo.setId(docId);
            if (!doctorSaveOrUpdateList.stream()
                    .map(doc -> doc.getCode()).distinct()
                    .collect(Collectors.toList()).contains(doctorInfo.getCode())) {
                doctorSaveOrUpdateList.add(doctorInfo);
            }
        });
        if (ListUtil.isNotEmpty(doctorSaveOrUpdateList)) {
            doctorInfoService.saveOrUpdateBatch(doctorSaveOrUpdateList);
        }
    }

    /**
     * 对接---获取挂号信息
     * 某一时刻患者只可能在一家医院，所以获取到的挂号信息只能是当前医院的，当出现江干的大小医院情况时可采用2种：
     * 1、预问诊必须选择小医院，对方接口小医院要求必传；2、his返回时间最近的一家医院挂号信息(可能不准确)。
     * 大小医院信息使用his返回来的(未选择小医院时有用)
     *
     * @param signInVO
     * @return
     */
    private List<RegisterInfoDTO> getRegisterInfo(SignInVO signInVO) {
        if (!signInVO.getHospitalCode().equals("33010400")) {
            return null;
        }
        String retJson = "  [{"
                + "\"hospitalCode\": \"33010400\","
                + "\"hospitalName\": \"江干区卫计局\","
                + "\"sonHospitalCode\": \"33010480\","
                + "\"sonHospitalName\": \"四季青街道社区卫生服务中心\","
                + "\"patientInfo\": {"
                + "	\"birthday\": \"1984-10-08 10:20:23\","
                + "\"code\": \"1747\","
                + "\"idNo\": \"330104198410083034\","
                + "	\"hospitalCode\": \"33010400\","
                + "	\"sex\": 1,"
                + "	\"identityNum\": \"330104198410083034\","
                + "	\"name\": \"沈利峰\""
                + "},"
                + "\"detail\": [{"
                + " \"hospitalDeptCode\": \"2127\","
                + "   \"hospitalDeptName\": \"中医科\","
                //                + "  \"doctorInfo\": {"
                //                + "    \"code\": \"000\","
                //                + "     \"hospitalCode\": \"33010400\","
                //                + "    \"name\": \"普通\""
                //                + "},"
                //                + "     \"recordId\": \"9043516\","
                + "  \"recordTime\": \"2019-12-05 12:29:55\","
                + " \"registerNum\": \"1\""
                + "},{"
                + "\"hospitalDeptCode\": \"2533\","
                + " \"hospitalDeptName\": \"机神全科\","
                //                + " \"doctorInfo\": {"
                //                + "\"code\": \"000\","
                //                + " \"hospitalCode\": \"33010400\","
                //                + "\"name\": \"普通\""
                //                + "},"
                //                + "  \"recordId\": \"9043512\","
                + " \"recordTime\": \"2019-12-05 12:23:09\","
                + " \"registerNum\": \"1\""
                + "}]"
                + "},"
                + "{"
                + "  \"hospitalCode\": \"33010400\","
                + "\"hospitalName\": \"江干区卫计局\","
                + " \"sonHospitalCode\": \"33010490\","
                + " \"sonHospitalName\": \"闸弄口街道社区卫生服务中心\","
                + "\"patientInfo\": {"
                + " \"birthday\": \"1984-10-08 10:20:23\","
                + "\"code\": \"1747\","
                + " \"idNo\": \"330104198410083034\","
                + " \"hospitalCode\": \"33010400\","
                + " \"sex\": 1,"
                + "  \"identityNum\": \"330104198410083034\","
                + "  \"name\": \"沈利峰\""
                + "},"
                + " \"detail\": [{"
                + "  \"hospitalDeptCode\": \"2127\","
                + "\"hospitalDeptName\": \"中医科\","
                //                + " \"doctorInfo\": {"
                //                + "  \"code\": \"000\","
                //                + " \"hospitalCode\": \"33010400\","
                //                + "  \"name\": \"普通\""
                //                + "},"
                //                + " \"recordId\": \"9043516\","
                + " \"recordTime\": \"2019-12-05 12:29:55\","
                + "  \"registerNum\": \"1\""
                + "},{"
                + " \"hospitalDeptCode\": \"2533\","
                + "    \"hospitalDeptName\": \"机神全科\","
                //                + "   \"doctorInfo\": {"
                //                + "   \"code\": \"000\","
                //                + "  \"hospitalCode\": \"33010400\","
                //                + "  \"name\": \"普通\""
                //                + "},"
                //                + "\"recordId\": \"9043512\","
                + "   \"recordTime\": \"2019-12-05 12:23:09\","
                + "  \"registerNum\": \"1\""
                + "}]"
                + "}"
                + "]";

        //        List<RegisterInfoDTO> rifList = GsonUtil.toList(retJson, RegisterInfoDTO.class);
        List<RegisterInfoDTO> rifList = JSON.parseArray(retJson, RegisterInfoDTO.class);
        System.out.println(rifList);
        if (StringUtil.isBlank(signInVO.getSonHospitalCode())) {
            return rifList;
        }

        Map<String, List<RegisterInfoDTO>> registerInfoDTOListMap = rifList.stream().collect(Collectors.groupingBy(RegisterInfoDTO::getSonHospitalCode));

        return registerInfoDTOListMap.get(signInVO.getSonHospitalCode());
    }

    /**
     * 病历引用时，更新患者医生科室信息
     *
     * @param inquiryQuoteVO
     * @return
     */
    public InquiryQuoteVO inquiryQuote(InquiryQuoteVO inquiryQuoteVO) {
        List<String> hospitalCodeList = Lists.newArrayList();
        hospitalCodeList.add(inquiryQuoteVO.getHospitalCode());

        String hospitalCode = inquiryQuoteVO.getHospitalCode();
        String hospitalName = inquiryQuoteVO.getHospitalName();

        if (StringUtil.isNotBlank(inquiryQuoteVO.getSonHospitalCode())) {
            hospitalCodeList.add(inquiryQuoteVO.getSonHospitalCode());
            hospitalCode = inquiryQuoteVO.getSonHospitalCode();
            hospitalName = inquiryQuoteVO.getSonHospitalName();
        }

        QueryWrapper<HospitalInfo> hospitalInfoQe = new QueryWrapper<>();
        hospitalInfoQe.in("code", hospitalCodeList);
        Map<String, Long> hospitalInfoIdMap = hospitalInfoFacade.list(hospitalInfoQe)
                .stream().collect(Collectors.toMap(HospitalInfo::getCode, i -> i.getId()));

        inquiryQuoteVO.setHospitalId(hospitalInfoIdMap.get(inquiryQuoteVO.getHospitalCode()));
        if (StringUtil.isNotBlank(inquiryQuoteVO.getSonHospitalCode())) {
            inquiryQuoteVO.setSonHospitalId(hospitalInfoIdMap.get(inquiryQuoteVO.getSonHospitalCode()));
        }

        Date now = DateUtil.now();
        if (inquiryQuoteVO.getDeptInfo() != null) {
            QueryWrapper<HospitalDept> hospitalDeptQe = new QueryWrapper<>();
            hospitalDeptQe.eq("hospital_code", hospitalCode);
            hospitalDeptQe.eq("code", inquiryQuoteVO.getDeptInfo().getCode());
            HospitalDept hospitalDept = hospitalDeptFacade.getOne(hospitalDeptQe, false);
            Long deptId = null;
            if (hospitalDept == null) {
                hospitalDept = new HospitalDept();
                hospitalDept.setGmtCreate(now);
                hospitalDept.setHospitalCode(hospitalCode);
                hospitalDept.setHospitalName(hospitalName);
                hospitalDept.setconceptDeptName("全科");
            } else {
                deptId = hospitalDept.getId().longValue();
            }
            BeanUtil.copyProperties(inquiryQuoteVO.getDeptInfo(), hospitalDept);
            hospitalDept.setGmtModified(now);
            hospitalDept.setId(deptId);
            hospitalDeptFacade.saveOrUpdate(hospitalDept);
            inquiryQuoteVO.getDeptInfo().setId(hospitalDept.getId());
        }

        if (inquiryQuoteVO.getDoctorInfo() != null) {
            QueryWrapper<DoctorInfo> doctorInfoQe = new QueryWrapper<>();
            doctorInfoQe.eq("hospital_code", inquiryQuoteVO.getHospitalCode());
            doctorInfoQe.eq("code", inquiryQuoteVO.getDoctorInfo().getCode());
            DoctorInfo doctorInfo = doctorInfoFacade.getOne(doctorInfoQe, false);
            Long doctorId = null;
            if (doctorInfo == null) {
                doctorInfo = new DoctorInfo();
                doctorInfo.setGmtCreate(now);
                doctorInfo.setHospitalCode(inquiryQuoteVO.getHospitalCode());
            } else {
                doctorId = doctorInfo.getId().longValue();
            }
            BeanUtil.copyProperties(inquiryQuoteVO.getDoctorInfo(), doctorInfo);
            doctorInfo.setGmtModified(now);
            doctorInfo.setId(doctorId);
            doctorInfoFacade.saveOrUpdate(doctorInfo);
            inquiryQuoteVO.getDoctorInfo().setId(doctorInfo.getId());
        }

        QueryWrapper<PatientInfo> patientInfoQe = new QueryWrapper<>();
        patientInfoQe.eq("hospital_code", inquiryQuoteVO.getHospitalCode());
        patientInfoQe.eq("name", inquiryQuoteVO.getPatientInfo().getName());
        patientInfoQe.and(a ->
                a.eq("id_no", inquiryQuoteVO.getPatientInfo().getIdentityNum())
                        .or()
                        .eq("identity_num", inquiryQuoteVO.getPatientInfo().getIdentityNum()));
        PatientInfo patientInfo = getOne(patientInfoQe, false);
        Long patientId = null;
        if (patientInfo == null) {
            patientInfo = new PatientInfo();
            patientInfo.setGmtCreate(now);
            patientInfo.setHospitalCode(inquiryQuoteVO.getHospitalCode());
        } else {
            patientId = patientInfo.getId().longValue();
        }
        BeanUtil.copyProperties(inquiryQuoteVO.getPatientInfo(), patientInfo);
        patientInfo.setGmtModified(now);
        patientInfo.setId(patientId);
        saveOrUpdate(patientInfo);
        inquiryQuoteVO.getPatientInfo().setId(patientInfo.getId());

        return inquiryQuoteVO;
    }

}